@@ -25,8 +25,10 @@ def test_resource_create_configuration_metadata():
     }])
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context1 = {'ignore_auth': False, 'user': user['name']}
-    dataset = make_dataset(create_context1, owner_org, with_resource=False,
+    create_context1 = {'ignore_auth': False,
+                       'user': user['name'],
+                       'api_version': 3}
+    dataset = make_dataset(create_context1, owner_org,
                            activate=False)
     path = data_path / "calibration_beads_47.rtdc"
     with path.open('rb') as fd:
@@ -58,8 +60,10 @@ def test_resource_create_configuration_metadata_invalid():
     }])
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context1 = {'ignore_auth': False, 'user': user['name']}
-    dataset = make_dataset(create_context1, owner_org, with_resource=False,
+    create_context1 = {'ignore_auth': False,
+                       'user': user['name'],
+                       'api_version': 3}
+    dataset = make_dataset(create_context1, owner_org,
                            activate=False)
     path = data_path / "calibration_beads_47.rtdc"
     with path.open('rb') as fd:
@@ -88,8 +92,10 @@ def test_resource_create_configuration_supplement():
     }])
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context1 = {'ignore_auth': False, 'user': user['name']}
-    dataset = make_dataset(create_context1, owner_org, with_resource=False,
+    create_context1 = {'ignore_auth': False,
+                       'user': user['name'],
+                       'api_version': 3}
+    dataset = make_dataset(create_context1, owner_org,
                            activate=False)
     path = data_path / "calibration_beads_47.rtdc"
     with path.open('rb') as fd:
@@ -120,8 +126,10 @@ def test_resource_create_configuration_supplement_invalid_value():
     }])
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context1 = {'ignore_auth': False, 'user': user['name']}
-    dataset = make_dataset(create_context1, owner_org, with_resource=False,
+    create_context1 = {'ignore_auth': False,
+                       'user': user['name'],
+                       'api_version': 3}
+    dataset = make_dataset(create_context1, owner_org,
                            activate=False)
     path = data_path / "calibration_beads_47.rtdc"
     with path.open('rb') as fd:
@@ -151,8 +159,10 @@ def test_resource_create_custom_upload_name_overridden():
     }])
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context1 = {'ignore_auth': False, 'user': user['name']}
-    dataset = make_dataset(create_context1, owner_org, with_resource=False,
+    create_context1 = {'ignore_auth': False,
+                       'user': user['name'],
+                       'api_version': 3}
+    dataset = make_dataset(create_context1, owner_org,
                            activate=False)
     path = data_path / "calibration_beads_47.rtdc"
     # create the first resource
@@ -176,7 +186,8 @@ def test_resource_create_package_id_missing():
     user = factories.User()
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context = {'ignore_auth': False, 'user': user['name']}
+    create_context = {'ignore_auth': False,
+                      'user': user['name'], 'api_version': 3}
 
     path = data_path / "calibration_beads_47.rtdc"
     with path.open('rb') as fd:
@@ -202,8 +213,10 @@ def test_resource_create_restrict_extensions():
     }])
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context1 = {'ignore_auth': False, 'user': user['name']}
-    dataset = make_dataset(create_context1, owner_org, with_resource=False,
+    create_context1 = {'ignore_auth': False,
+                       'user': user['name'],
+                       'api_version': 3}
+    dataset = make_dataset(create_context1, owner_org,
                            activate=False)
     tdir = tempfile.mkdtemp(prefix="test_dcor_schemas_")
     path = pathlib.Path(tdir) / "bad_extension.docx"
@@ -233,8 +246,10 @@ def test_resource_create_same_name_forbidden():
     }])
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context1 = {'ignore_auth': False, 'user': user['name']}
-    dataset = make_dataset(create_context1, owner_org, with_resource=False,
+    create_context1 = {'ignore_auth': False,
+                       'user': user['name'],
+                       'api_version': 3}
+    dataset = make_dataset(create_context1, owner_org,
                            activate=False)
     path = data_path / "calibration_beads_47.rtdc"
     # create the first resource
@@ -249,7 +264,8 @@ def test_resource_create_same_name_forbidden():
                             name=path.name,
                             )
     # attempt creation of second resource with same name
-    create_context2 = {'ignore_auth': False, 'user': user['name']}
+    create_context2 = {'ignore_auth': False,
+                       'user': user['name'], 'api_version': 3}
     with path.open('rb') as fd:
         upload = cgi.FieldStorage()
         upload.filename = path.name
@@ -274,8 +290,9 @@ def test_resource_create_weird_characters():
     }])
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context1 = {'ignore_auth': False, 'user': user['name']}
-    dataset = make_dataset(create_context1, owner_org, with_resource=False,
+    create_context1 = {'ignore_auth': False,
+                       'user': user['name'], 'api_version': 3}
+    dataset = make_dataset(create_context1, owner_org,
                            activate=False)
     path = data_path / "calibration_beads_47.rtdc"
     tdir = tempfile.mkdtemp(prefix="test_dcor_schemas_")
